=========================================================================
``psyclone.tests.psyir.frontend.fparser2_subscript_triplet_handler_test``
=========================================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_subscript_triplet_handler_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_subscript_triplet_handler_test
